* If you are storing identification numbers, rounding could matter. 
* If the identification numbers are integers and take 9 digits or less, 
* store them as longs; otherwise, store them as doubles. 
* doubles have 16 digits of accuracy.

version 8
clear
set matsize 180
set logtype text
set mem 900m
set more off

cd "$root"

capture log close
log using "brazempl/logs/repl-pia-data.log", replace

foreach yr in 90 92 93 94 95 96 97 98 {

disp 
disp in green "Year: " in yellow "19`yr'"
disp 

tempfile list`yr'
use "brazdspl/pia/random-3firm-firmlist-rndmnr", clear
keep cellid currno firm year indsp niv50 contyrs
keep if year==19`yr'
drop year
sort firm
rename firm firmid
compress
egen firmgrp = group(indsp niv50 contyrs currno)
label var firmgrp "Firm group ID (cellid contyrs)"
order firmid firmgrp
duplicates tag firmid, gen(_dupl)
count if _dupl>0
if `r(N)' > 0 {
  disp as err "Duplicate firm IDs"
  STOP
  }
sort firmid
save `list`yr''

tempfile cells`yr'
local sec 4
use "brazempl/est/firmpred-edu-sec`sec'-`yr'", clear
* foreach sec in 1 2 5 {
*   append using "brazempl/est/firmpred-edu-sec`sec'-`yr'"
*   }
label var xbfirm "Avg. Predicted Wage (in plant & firm)"
label var avgpsihat "Avg. Establishment Effect (in firm)"
sort firmid
merge firmid using "brazempl/data/firm-skills-`yr'", nokeep
label var labf_skil_tot "Share Engin'rs, Tech's, Managers"
drop _m
sort firmid
merge firmid using `list`yr''
capture label drop piarais
label define piarais 1 "RAIS SP establishments but no PIA firm" 2 "PIA firms but no RAIS SP establishment" 3 "RAIS SP establishments in PIA firm"
label values _merge piarais
tab _m
keep if _m==3
keep firmid cellid currno firmgrp xbfirm avgpsihat avgxbhat labf_skil_tot
order firmid cellid currno firmgrp xbfirm avgpsihat avgxbhat labf_skil_tot
label var xbfirm "Avg Pred Wage (plant)"
label var avgpsihat "Avg Estm't Effect (firm)"
label var avgxbhat "Avg Pred Wage (firm)"
label var labf_skil_tot "Sh. Eng's/Tech's/Manag's"
local i 0
foreach var in xbfirm avgpsihat avgxbhat labf_skil_tot {
    local i = `i' + 1
    local lbl`i' : variable label `var' 
    }
collapse (count) mrgfrms_obs=firmid (mean) xbfirm avgpsihat avgxbhat labf_skil_tot, by(firmgrp)
local i 0
foreach var in xbfirm avgpsihat avgxbhat labf_skil_tot {
    local i = `i' + 1
    label var `var' "`lbl`i'' [mean]"
    }
sort firmgrp
compress
save `cells`yr''

use "brazdspl/pia/random-3firm-grpid-rndmnr", clear
keep if year==19`yr'
keep firmgrp niv50 frms_obs kappa1 mu lnvaladd sales labfbl labfwh profit apimmo1x lntfp lnlp 
rename kappa1 kappa
label var kappa "Foreign Machinery Share"
label var mu "Foreign Intermediates Share"
gen ln_empl = ln(labfbl + labfwh)
gen labf_wh_tot  = labfwh/(labfbl + labfwh)
label var labf_wh_tot "Share White Collar Workers"
label var ln_empl "Log Employees"
drop labfbl labfwh
gen ln_cap = ln(apimmo1x)
label var ln_cap "Log Capital"
gen lnsales = ln(sales)
drop sales
gen ln_valadd_empl = lnvaladd - ln_empl
drop lnvaladd
label var ln_valadd_empl "Log of Value Added / Labor Force"
gen ln_sales_empl = lnsales - ln_empl
drop lnsales
label var ln_sales_empl "Log of Sales / Labor Force"
gen profit_cap = profit / apimmo1x
drop profit apimmo1x
label var profit_cap "Operating Income / Capital"
gen ln_cap_empl = ln_cap - ln_empl
label var ln_cap_empl "Log of Capital / Labor Force"
order firmgrp niv50 ln_empl ln_cap ln_valadd_empl ln_sales_empl ln_cap_empl profit_cap labf_wh_tot lntfp lnlp kappa mu frms_obs
label var niv50 "Sector (Nivel 50)"
sort firmgrp
merge firmgrp using `cells`yr''
capture label drop piacells
label define piacells 1 "RAIS&PIA firms but no cell match" 2 "Firms in cells but no RAIS&PIA match" 3 "Firms in cells matched with RAIS&PIA"
label values _merge piacells
tab _m
drop _m
order firmgrp niv50 xbfirm avgpsihat avgxbhat ln_empl ln_cap ln_valadd_empl ln_sales_empl ln_cap_empl profit_cap labf_wh_tot labf_skil_tot lntfp lnlp kappa mu frms_obs

drop if mrgfrms_obs==. | frms_obs==.
qui do "brazdspl/auxil/niv50.do"
label values niv50 niv50
duplicates tag firmgrp, gen(_dupl)
qui count if _dupl>0
if `r(N)' {
    disp as err "Duplicate firm groups per year"
    STOP
    }
drop _dupl
compress
sort firmgrp
save "brazempl/use-firms-`yr'", replace

}

log close
cd "$home"
