version 8
clear
set matsize 180
set logtype text
set mem 900m
capture set mem 950m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture program drop corrtab
program define corrtab
    args regname yr sec
    predict xbhat if e(sample)
    replace xbhat = xbhat - _coef[_cons]
    gen psihat = _coef[_cons]
    predict eiw, res
    corr lnwage xbhat eiw
    matrix accum corrplain`yr'sec`sec'`regname' = lnwage xbhat eiw, nocons dev means(corrplain`yr'sec`sec'`regname'_means)
    matrix corrplain`yr'sec`sec'`regname'_sdev = corrplain`yr'sec`sec'`regname'_means
    local j 0
    foreach var in lnwage xbhat eiw {
        local j = `j' + 1
        qui summ `var'
        local entry = int(`r(sd)'*10000)/10000
        matrix corrplain`yr'sec`sec'`regname'_sdev[1,`j']=`entry'
        }
    matrix corrplain`yr'sec`sec'`regname'_tbl = corr(corrplain`yr'sec`sec'`regname')
    matrix corrplain`yr'sec`sec'`regname'_tbl = corrplain`yr'sec`sec'`regname'_sdev ' , corrplain`yr'sec`sec'`regname'_tbl
    matrix corrplain`yr'sec`sec'`regname'_tbl = corrplain`yr'sec`sec'`regname'_means ' , corrplain`yr'sec`sec'`regname'_tbl
    matname corrplain`yr'sec`sec'`regname'_tbl mean sdev, columns(1..2) explicit
    * if `sec'==1 | `sec'==4 {
    preserve
      gen double pred_exper = potexper*_coef[potexper] + potxper2*_coef[potxper2] + potxper3*_coef[potxper3] + potxper4*_coef[potxper4] 
      gen double pred_occu = indprof*_coef[indprof] + indtech*_coef[indtech] + indwhit*_coef[indwhit] + indsklb*_coef[indsklb] 
      if "`regname'"=="indgrad" {
        gen double pred_edu = indhigh*_coef[indhigh] + indscoll*_coef[indscoll] + indgrad*_coef[indgrad] 
        gen double pred_sex = indfem * ( _coef[indfem] + fem_potexper*_coef[fem_potexper] + fem_potxper2*_coef[fem_potxper2] + fem_potxper3*_coef[fem_potxper3] + fem_potxper4*_coef[fem_potxper4] + fem_indprof*_coef[fem_indprof] + fem_indtech*_coef[fem_indtech] + fem_indwhit*_coef[fem_indwhit] + fem_indsklb*_coef[fem_indsklb] + fem_indhigh*_coef[fem_indhigh] + fem_indscoll*_coef[fem_indscoll] + fem_indgrad*_coef[fem_indgrad] )
        }
      if "`regname'"=="edu" {
        gen double pred_edu = indprim*_coef[indprim] + indhigh*_coef[indhigh] + indscoll*_coef[indscoll]
        gen double pred_sex = indfem * ( _coef[indfem] + fem_potexper*_coef[fem_potexper] + fem_potxper2*_coef[fem_potxper2] + fem_potxper3*_coef[fem_potxper3] + fem_potxper4*_coef[fem_potxper4] + fem_indprof*_coef[fem_indprof] + fem_indtech*_coef[fem_indtech] + fem_indwhit*_coef[fem_indwhit] + fem_indsklb*_coef[fem_indsklb] + fem_indprim*_coef[fem_indprim] + fem_indhigh*_coef[fem_indhigh] + fem_indscoll*_coef[fem_indscoll] )
        }
      if "`regname'"=="noedu" {
        gen double pred_edu = 0
        gen double pred_sex = indfem * ( _coef[indfem] + fem_potexper*_coef[fem_potexper] + fem_potxper2*_coef[fem_potxper2] + fem_potxper3*_coef[fem_potxper3] + fem_potxper4*_coef[fem_potxper4] + fem_indprof*_coef[fem_indprof] + fem_indtech*_coef[fem_indtech] + fem_indwhit*_coef[fem_indwhit] + fem_indsklb*_coef[fem_indsklb] + 0 )
        }
      qui gen _chk = pred_exper + pred_occu + pred_edu + pred_sex - xbhat
      qui summ _chk, meanonly
      if abs(`r(mean)')>.00001 {
        summ _chk
        disp as err "Invalid component decomposition"
        STOP
        }   
      keep worker firm plant lnwage xbhat psihat eiw pred_exper pred_occu pred_edu pred_sex
      * qui gen _chk = lnwage - xbhat - psihat - eiw
      * qui summ _chk, meanonly
      * if abs(`r(mean)')>.00001 {
      *   summ _chk
      *   disp as err "Invalid component decomposition"
      *  STOP
      *   }
      * drop _chk
      sort worker firm plant
      compress
      save "brazempl/est/v1/wageplaincomponents-`regname'-sec`sec'-`yr'", replace
    restore
    drop xbhat psihat eiw
end

capture log close
local run = 0
local exit = 0
while ~`exit' {
    local run = `run' + 1
    capture confirm new file "brazempl/logs/reg-worker-plain-round`run'.log"
    if _rc~=602 {
      local exit=1
      }
}
log using "brazempl/logs/reg-worker-plain-round`run'.log", replace

*YR forvalues yr = 90/98 {  /* 90/98 */
local yr 90 /*/
local sec 1 /*/
foreach yr in 90 97 {  /* 90 97 */
  foreach sec in 1 2 4 5  {  /* 1 2 4 5 */
    use "brazempl/use-brazempl-`yr'", clear
    local secname : label sector `sec'
    disp
    disp in green "Year: " in yellow "19`yr'" in green ", Sector: " in yellow "`sec'" in green " (" in yellow "`secname'" in green ")"
    disp
    * tab sector
    * tab sector, nolab
    keep if sector==`sec'
    sort worker firm plant
    foreach var in potexper potxper2 potxper3 potxper4 tenuryr tenr2 tenr3 tenr4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indprim indhigh indprim_alt indhigh_alt indscoll indgrad indprof indtech indwhit indsklb indunsklb {
      local dattyp = ""
      if substr("`var'",1,3)=="ind" {
          local dattyp = "byte"
          }
      gen `dattyp' fem_`var' = indfem * `var'
      local lbl : variable label `var'
      local lbl = subinstr("`lbl'"," (at plant)","",.)
      local lbl = subinstr("`lbl'"," Term","",.)
      local lbl = subinstr("`lbl'"," Occupation","",.)
      local lbl = subinstr("`lbl'"," Education","",.)
      local lbl = "Fem. " + "`lbl'" + " Interact."
      label var fem_`var' "`lbl'"
      }
    compress
    drop wage decwageyr lndecwage sector indgoodpis
    iis plant

    reg lnwage tenuryr tenr2 tenr3 tenr4                   indprof indtech indwhit indsklb         indhigh indscoll indgrad indfem fem_tenuryr fem_tenr2 fem_tenr3 fem_tenr4                       fem_indprof fem_indtech fem_indwhit fem_indsklb             fem_indhigh fem_indscoll fem_indgrad
    est2vec wageplain`yr'sec`sec', replace vars(potexper potxper2 potxper3 potxper4 tenuryr tenr2 tenr3 tenr4 indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indprim indhigh indprim_alt indhigh_alt indscoll indgrad indprof indtech indwhit indsklb indunsklb indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_tenuryr fem_tenr2 fem_tenr3 fem_tenr4 fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8 fem_indprim fem_indhigh fem_indprim_alt fem_indhigh_alt fem_indscoll fem_indgrad fem_indprof fem_indtech fem_indwhit fem_indsklb fem_indunsklb _cons) e(r2 r2_a r2_w r2_o r2_b mss tss corr sigma_u sigma_e df_r df_m) name(yr`yr'sec`sec'tenr)
    reg lnwage tenuryr tenr2 tenr3 tenr4 potexper          indprof indtech indwhit indsklb                                  indfem fem_tenuryr fem_tenr2 fem_tenr3 fem_tenr4 fem_potexper          fem_indprof fem_indtech fem_indwhit fem_indsklb                                                 
    est2vec wageplain`yr'sec`sec', addto(wageplain`yr'sec`sec') name(yr`yr'sec`sec'tenrage)
    reg lnwage potexper potxper2 potxper3 potxper4 tenuryr indprof indtech indwhit indsklb indprim indhigh indscoll         indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_tenuryr fem_indprof fem_indtech fem_indwhit fem_indsklb fem_indprim fem_indhigh fem_indscoll            
    est2vec wageplain`yr'sec`sec', addto(wageplain`yr'sec`sec') name(yr`yr'sec`sec'potx)

    reg lnwage potexper potxper2 potxper3 potxper4         indprof indtech indwhit indsklb         indhigh indscoll indgrad indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4             fem_indprof fem_indtech fem_indwhit fem_indsklb             fem_indhigh fem_indscoll fem_indgrad
    est2vec wageplain`yr'sec`sec', addto(wageplain`yr'sec`sec') name(yr`yr'sec`sec'indgrad)
    corrtab indgrad `yr' `sec'

    reg lnwage potexper potxper2 potxper3 potxper4         indprof indtech indwhit indsklb indprim indhigh indscoll indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4             fem_indprof fem_indtech fem_indwhit fem_indsklb fem_indprim fem_indhigh fem_indscoll
    est2vec wageplain`yr'sec`sec', addto(wageplain`yr'sec`sec') name(yr`yr'sec`sec'edu)
    corrtab edu `yr' `sec'
    
    reg lnwage potexper potxper2 potxper3 potxper4         indprof indtech indwhit indsklb                          indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4             fem_indprof fem_indtech fem_indwhit fem_indsklb                                     
    est2vec wageplain`yr'sec`sec', addto(wageplain`yr'sec`sec') name(yr`yr'sec`sec'noedu)
    corrtab noedu `yr' `sec'
    
    reg lnwage potexper potxper2 potxper3 potxper4         indprof indtech indwhit indsklb indschlg1 indschlg2 indschlg3 indschlg4 indschlg5 indschlg6 indschlg7 indschlg8 indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4             fem_indprof fem_indtech fem_indwhit fem_indsklb fem_indschlg1 fem_indschlg2 fem_indschlg3 fem_indschlg4 fem_indschlg5 fem_indschlg6 fem_indschlg7 fem_indschlg8
    * est2vec wageplain`yr'sec`sec', addto(wageplain`yr'sec`sec') name(yr`yr'sec`sec'fuledu)
    * corrtab fuledu `yr' `sec'
    
    reg lnwage potexper potxper2 potxper3 potxper4         indprof indtech indwhit indsklb indprim_alt indhigh_alt indscoll indfem fem_potexper fem_potxper2 fem_potxper3 fem_potxper4             fem_indprof fem_indtech fem_indwhit fem_indsklb fem_indprim_alt fem_indhigh_alt fem_indscoll
    * est2vec wageplain`yr'sec`sec', addto(wageplain`yr'sec`sec') name(yr`yr'sec`sec'altedu)
    * corrtab altedu `yr' `sec'
    
    est2tex corrplain`yr'sec`sec'indgrad, replace dropall preserve ready digits(4) fancy path(brazempl/tex/v1/corr)
    est2tex corrplain`yr'sec`sec'edu, replace dropall preserve ready digits(4) fancy path(brazempl/tex/v1/corr)
    est2tex corrplain`yr'sec`sec'noedu, replace dropall preserve ready digits(4) fancy path(brazempl/tex/v1/corr)
    est2tex wageplain`yr'sec`sec', replace dropall preserve mark(it) digits(4) fancy path(brazempl/tex/v1/wage) label
  }
}

* Reformat estimation output tables
foreach var in indgrad edu noedu {
*YR forvalues yr = 90/98 {
   foreach yr in 90 97 {
    foreach sec in 1 2 4 5 {
      matload corrplain`yr'sec`sec'`var'_tbl, dropall path(brazempl/tex/v1/corr) over
      est2tex corrplain`yr'sec`sec'`var', replace dropall preserve ready digits(3) fancy p(brazempl/tex/v1/corr)
      }
    }
  }

log close
cd "$home"
