version 8
clear
set matsize 180
set more off
adopath + "brazdspl/%stata/ado"

mat drop _all

cd "$root"

capture program drop replexp
program define replexp
  replace mean = mean / 100 if substr(_rowname,-8,8)=="potxper2" | substr(_rowname,-5,5)=="tenr2"
  replace sd = sd / 100 if substr(_rowname,-8,8)=="potxper2" | substr(_rowname,-5,5)=="tenr2"
  replace mean = mean / 1000 if substr(_rowname,-8,8)=="potxper3" | substr(_rowname,-5,5)=="tenr3" 
  replace sd = sd / 1000 if substr(_rowname,-8,8)=="potxper3" | substr(_rowname,-5,5)=="tenr3"
  replace mean = mean / 10000 if substr(_rowname,-8,8)=="potxper4" | substr(_rowname,-5,5)=="tenr4"
  replace sd = sd / 10000 if substr(_rowname,-8,8)=="potxper4" | substr(_rowname,-5,5)=="tenr4"
end

/* Load variable names and save for est2tex */

insheet using "brazempl/tex/regressor-list.tex", delimiter("&") clear
rename v1 _rowname
rename v2 _rowlbl
replace _rowname = trim(_rowname)
replace _rowlbl = trim(_rowlbl)
drop if _rowname=="" & _rowlbl==""
sort _rowname
compress
save "brazempl/tex/v1/tables/lnwmeanshr_rowlbl", replace
save "brazempl/tex/v1/tables/shares_rowlbl", replace
save "brazempl/tex/v1/tables/shares90_rowlbl", replace
save "brazempl/tex/v1/tables/shares97_rowlbl", replace
save "brazempl/tex/v1/tables/shares9097_rowlbl", replace
save "brazempl/tex/v1/tables/compest9097_rowlbl", replace
save "brazempl/tex/v1/tables/compest9097_noedu_rowlbl", replace
save "brazempl/tex/v1/tables/prflcomp_rowlbl", replace
save "brazempl/tex/v1/tables/corrcompnoedu_rowlbl", replace
save "brazempl/tex/v1/tables/firmcomp_rowlbl", replace
save "brazempl/tex/v1/tables/braz90edu_rowlbl", replace
save "brazempl/tex/v1/tables/brazplain90edu_rowlbl", replace
save "brazempl/tex/v1/tables/braz97edu_rowlbl", replace
save "brazempl/tex/v1/tables/brazplain97edu_rowlbl", replace
save "brazempl/tex/v1/tables/brazplaincomp_rowlbl", replace
save "brazempl/tex/v1/tables/prflplaincomp_rowlbl", replace
save "brazempl/tex/v1/tables/prflbrsec_rowlbl", replace
save "brazempl/tex/v1/tables/prflbrsec_pap_rowlbl", replace
save "brazempl/tex/v1/tables/prflbrsecplain_rowlbl", replace
save "brazempl/tex/v1/summ/count_rowlbl", replace
save "brazempl/tex/v1/tables/summtex9097_rowlbl", replace
save "brazempl/tex/v1/tables/summtex90pt1_rowlbl", replace
save "brazempl/tex/v1/tables/summtex90pt2_rowlbl", replace
save "brazempl/tex/v1/tables/summtex97pt1_rowlbl", replace
save "brazempl/tex/v1/tables/summtex97pt2_rowlbl", replace
save "brazempl/tex/v1/tables/summtexpia_rowlbl", replace
save "brazempl/tex/v1/tables/lnwcomp90manuf_rowlbl", replace
save "brazempl/tex/v1/tables/lnwcomp97manuf_rowlbl", replace
save "brazempl/tex/v1/tables/lnwcomp90sqcfdev_rowlbl", replace
save "brazempl/tex/v1/tables/lnwcomp97sqcfdev_rowlbl", replace
save "brazempl/tex/v1/tables/lnwcomp9097manuf_rowlbl", replace
save "brazempl/tex/v1/tables/lnwcomp90sqcfdev_pc_rowlbl", replace
save "brazempl/tex/v1/tables/lnwcomp97sqcfdev_pc_rowlbl", replace
save "brazempl/tex/v1/tables/lnwcomp9097manuf_pc_rowlbl", replace
clear
 

/* Load estimates */

*YR foreach yr in 90 92 93 94 95 96 97 98 {
foreach yr in 90 97 {
  foreach sec in 4 5 2 1 {
    matload summtex`yr'sec`sec'_tbl, p(brazempl/tex/v1/summ) over
    }
  matload firm`yr'pia_tbl, path(brazempl/tex/v1/sec) over
  * matload sec`yr'pia_tbl, path(brazempl/tex/v1/sec) over
  }
foreach profile in edu occu sex {
 foreach type in comp brsec {
  matload prfl`type'`profile'_tbl, p(brazempl/tex/v1/tables) over dropall
  matload prfl`type'plain`profile'_tbl, p(brazempl/tex/v1/tables) over dropall
  }
 }


/* Summary Table Workers: Counts and Average Wages by Groups and Sectors in Brazil */

foreach type in lnwmean count {
 mat `type'_tbl = J(1,6,-999)
 foreach yr in 90 97 {
  foreach var in indfem indnocoll indblue {
   matload `type'`yr'`var'_tbl, p(brazempl/tex/v1/summ) over
   matname `type'`yr'`var'_tbl `yr'`var':0, rows(1) explicit
   matname `type'`yr'`var'_tbl `yr'`var':1, rows(2) explicit
   mat `type'_tbl = `type'_tbl \ `type'`yr'`var'_tbl
   local colnames : colfullnames `type'`yr'`var'_tbl
   }
  }
 matname `type'_tbl `colnames', columns(1..6) explicit
 mat `type'_tbl = `type'_tbl[2..rowsof(`type'_tbl),1..colsof(`type'_tbl)]
 matorder `type'_tbl, matrix(`type'_tbl) over ifc(Manufacturing Services Commerce Agriculture)
 }
est2tex lnwmean, ready replace dropall preserve path(brazempl/tex/v1/summ) fancy
est2tex count, ready replace dropall preserve path(brazempl/tex/v1/summ) fancy thousep

local rownames : rowfullnames count_tbl
local colnames : colfullnames count_tbl
mat grpshares = J(12,4,-999)
matname grpshares `rownames', rows(1..12) explicit
matname grpshares `colnames', columns(1..4) explicit
forvalues pair = 1/6 {
 forvalues col = 1/4 {
   local row1 = `pair' * 2 - 1
   local row2 = `pair' * 2
   mat grpshares[`row1',`col'] = count_tbl[`row1',`col'] / ( count_tbl[`row1',`col'] + count_tbl[`row2',`col'] )
   mat grpshares[`row2',`col'] = count_tbl[`row2',`col'] / ( count_tbl[`row1',`col'] + count_tbl[`row2',`col'] )
   }
  }
mat secshares = J(2,4,0)
matname secshares 90alloc 97alloc, rows(1..2) explicit
matname secshares `colnames', columns(1..4) explicit
local tot90 = 0
local tot97 = 0
forvalues col = 1/4 {
  forvalues row = 1/2 {
    mat secshares[1,`col'] = secshares[1,`col'] + count_tbl[`row',`col']
    mat secshares[2,`col'] = secshares[2,`col'] + count_tbl[6+`row',`col']
   }
  local tot90 = `tot90' + secshares[1,`col']
  local tot97 = `tot97' + secshares[2,`col']
  }
forvalues col = 1/4 {
  mat secshares[1,`col'] = secshares[1,`col'] / `tot90'
  mat secshares[2,`col'] = secshares[2,`col'] / `tot97'
  }
mat shares_tbl = grpshares \ secshares
mat drop grpshares secshares
est2tex shares, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy

mat seclnwmean_tbl = J(2,4,-999)
local row = 0
foreach yr in 90 97 {
  local row = `row' + 1
  local col = 0
  foreach sec in 4 5 2 1 {
    local col = `col' + 1
    mat seclnwmean_tbl[`row',`col'] = summtex`yr'sec`sec'_tbl[1,1]
    }
  }
local rownames : rowfullnames shares_tbl
mat lnwmeanshr_tbl = ( lnwmean_tbl \ seclnwmean_tbl ) , shares_tbl
matname lnwmeanshr_tbl `rownames', rows(1..14) explicit
matname lnwmeanshr_tbl lnw:Manuf lnw:Svcs lnw:Comm lnw:Agric sh:Manuf sh:Svcs sh:Comm sh:Agric, columns(1..8) explicit
est2tex lnwmeanshr, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(4)


/* Summary Share Tables Brazil */

capture program drop matkeep

foreach yr in 90 97 {
  foreach sec in 4 5 2 1 {
    matkeep summtex`yr'sec`sec'_tbl, mat(_educ`yr'sec`sec') ifrow(indprim indhigh indscoll indgrad)
    matkeep _educ`yr'sec`sec', ifcol(mean) mat(_educ`yr'sec`sec')
    mat _educ`yr'sec`sec' = _educ`yr'sec`sec' \ ( _educ`yr'sec`sec' ' * J(4,1,1) )
    mat _educ`yr'sec`sec' = _educ`yr'sec`sec' / _educ`yr'sec`sec'[5,1]
    matname _educ`yr'sec`sec' eductot, rows(5) explicit
    matkeep summtex`yr'sec`sec'_tbl, mat(_occu`yr'sec`sec') ifrow(indprof indtech indwhit indsklb indnoskl)
    matkeep _occu`yr'sec`sec', ifcol(mean) mat(_occu`yr'sec`sec')
    mat _occu`yr'sec`sec' = _occu`yr'sec`sec' \ ( _occu`yr'sec`sec' ' * J(5,1,1) )
    mat _occu`yr'sec`sec' = _occu`yr'sec`sec' / _occu`yr'sec`sec'[6,1]
    matname _occu`yr'sec`sec' occutot, rows(6) explicit
    matkeep summtex`yr'sec`sec'_tbl, mat(_sex`yr'sec`sec') ifrow(indfem)
    matkeep _sex`yr'sec`sec', ifcol(mean) mat(_sex`yr'sec`sec')
    mat _sex`yr'sec`sec' = _sex`yr'sec`sec' \ ( J(1,1,1) - _sex`yr'sec`sec' ) \ J(1,1,1)
    matname _sex`yr'sec`sec' indmasc sextot, rows(2..3) explicit
    matkeep summtex`yr'sec`sec'_tbl, mat(_tot`yr'sec`sec') ifrow(r(N))
    matkeep _tot`yr'sec`sec', ifcol(mean) mat(_tot`yr'sec`sec')
    mat _sh`yr'sec`sec' = _educ`yr'sec`sec' \ _occu`yr'sec`sec' \ _sex`yr'sec`sec' \ _tot`yr'sec`sec'
    mat drop _educ`yr'sec`sec' _occu`yr'sec`sec' _sex`yr'sec`sec' _tot`yr'sec`sec'
    }
  mat _shares`yr' = _sh`yr'sec4 , _sh`yr'sec5 , _sh`yr'sec2 , _sh`yr'sec1
  mat drop _sh`yr'sec1 _sh`yr'sec2 _sh`yr'sec4 _sh`yr'sec5
  mat _marg`yr' = ( _shares`yr' * _shares`yr'[rowsof(_shares`yr'),1..colsof(_shares`yr')] ' )
  mat _marg`yr' = _marg`yr' / _marg`yr'[rowsof(_marg`yr')-1,colsof(_marg`yr')]
  mat _marg`yr'[rowsof(_marg`yr'),colsof(_marg`yr')] = _shares`yr'[rowsof(_shares`yr'),1..colsof(_shares`yr')] * J(4,1,1)
  mat _shares`yr' = _shares`yr' , _marg`yr'
  matname _shares`yr' sec4 sec5 sec2 sec1 tot, columns(1..5) explicit 
  mat drop _marg`yr'
  }
mat _shares90 = ( lnwmeanshr_tbl[rownumb(lnwmeanshr_tbl,"90alloc"),5..8] , J(1,1,1) ) \ _shares90
mat _shares97 = ( lnwmeanshr_tbl[rownumb(lnwmeanshr_tbl,"97alloc"),5..8] , J(1,1,1) ) \ _shares97
matname _shares90 tot, columns(5) explicit
matname _shares97 tot, columns(5) explicit
mat shares90_tbl = _shares90
mat shares97_tbl = _shares97
est2tex shares90, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
est2tex shares97, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
matrix coleq _shares90 = yr90
matrix coleq _shares97 = yr97
mat shares9097_tbl = _shares90 , _shares97
matname shares9097_tbl secalloc, rows(1) explicit
mat drop _shares90 _shares97
est2tex shares9097, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(5)


/* Profile Tables for education, occupation, gender: Brazil 1990 and 1997 */

* Wage profile tables
foreach type in comp brsec {
  local cols = colsof(prfl`type'edu_tbl)
  local colnames : colfullnames prfl`type'edu_tbl
  mat prfl`type'_tbl = J(1,`cols',1) \ prfl`type'edu_tbl[1..3,1..`cols'] \ J(1,`cols',1) \ prfl`type'edu_tbl[4..6,1..`cols'] \ prfl`type'occu_tbl[1..4,1..`cols'] \ J(1,`cols',1) \ prfl`type'occu_tbl[5..8,1..`cols'] \ J(1,`cols',1) \ prfl`type'sex_tbl[1..2,1..`cols']
  matname prfl`type'_tbl grad:masc, rows(1) explicit
  matname prfl`type'_tbl grad:fem, rows(5) explicit 
  matname prfl`type'_tbl unskl:masc, rows(13) explicit
  matname prfl`type'_tbl unskl:fem, rows(18) explicit
  matname prfl`type'_tbl `colnames', columns(1..`cols') explicit
  forvalues col = 1/`cols' {
   foreach row in 1 2 4 {
     mat prfl`type'_tbl[`row',`col'] = prfl`type'_tbl[`row',`col'] / prfl`type'_tbl[3,`col']
     }
   mat prfl`type'_tbl[3,`col'] = prfl`type'_tbl[3,`col'] / prfl`type'_tbl[3,`col']
   foreach row in 5 6 8 {
     mat prfl`type'_tbl[`row',`col'] = prfl`type'_tbl[`row',`col'] / prfl`type'_tbl[7,`col']
     }
   mat prfl`type'_tbl[7,`col'] = prfl`type'_tbl[7,`col'] / prfl`type'_tbl[7,`col']
   }
  }
matorder prflbrsec_tbl, matrix(prflbrsec_tbl) over ifc(br90sec4 br97sec4 br90sec5 br97sec5 br90sec2 br97sec2 br90sec1 br97sec1)
est2tex prflbrsec, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(2 4 6)
matorder prflbrsec_tbl, matrix(prflbrsec_pap_tbl) ifc(br90sec4 br90sec5 br90sec2 br90sec1)
est2tex prflbrsec_pap, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
local rows = rowsof(prflcomp_tbl)
est2tex prflcomp, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy 

* OLS Wage profile tables
foreach type in comp brsec {
  local cols = colsof(prfl`type'plainedu_tbl)
  local colnames : colfullnames prfl`type'plainedu_tbl
  mat prfl`type'plain_tbl = J(1,`cols',1) \ prfl`type'plainedu_tbl[1..3,1..`cols'] \ J(1,`cols',1) \ prfl`type'plainedu_tbl[4..6,1..`cols'] \ prfl`type'plainoccu_tbl[1..4,1..`cols'] \ J(1,`cols',1) \ prfl`type'plainoccu_tbl[5..8,1..`cols'] \ J(1,`cols',1) \ prfl`type'plainsex_tbl[1..2,1..`cols']
  matname prfl`type'plain_tbl grad:masc, rows(1) explicit
  matname prfl`type'plain_tbl grad:fem, rows(5) explicit 
  matname prfl`type'plain_tbl unskl:masc, rows(13) explicit
  matname prfl`type'plain_tbl unskl:fem, rows(18) explicit
  matname prfl`type'plain_tbl `colnames', columns(1..`cols') explicit
  forvalues col = 1/`cols' {
   foreach row in 1 2 4 {
     mat prfl`type'plain_tbl[`row',`col'] = prfl`type'plain_tbl[`row',`col'] / prfl`type'plain_tbl[3,`col']
     }
   mat prfl`type'plain_tbl[3,`col'] = prfl`type'plain_tbl[3,`col'] / prfl`type'plain_tbl[3,`col']
   foreach row in 5 6 8 {
     mat prfl`type'plain_tbl[`row',`col'] = prfl`type'plain_tbl[`row',`col'] / prfl`type'plain_tbl[7,`col']
     }
   mat prfl`type'plain_tbl[7,`col'] = prfl`type'plain_tbl[7,`col'] / prfl`type'plain_tbl[7,`col']
   }
  }
matorder prflbrsecplain_tbl, matrix(prflbrsecplain_tbl) over ifc(br90sec4 br97sec4 br90sec5 br97sec5 br90sec2 br97sec2 br90sec1 br97sec1)
est2tex prflbrsecplain, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(2 4 6)
* local rows = rowsof(prflcompplain_tbl)
est2tex prflcompplain, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy 
matorder prflbrsec_tbl, matrix(_prflplaincomp_pt1) ifc(br90sec4 br97sec4)
matorder prflbrsecplain_tbl, matrix(_prflplaincomp_pt2) ifc(br90sec4 br97sec4)
mat colnames _prflplaincomp_pt2 = br90sec4plain br97sec4plain
mat prflplaincomp_tbl = _prflplaincomp_pt1 , _prflplaincomp_pt2
mat drop _prflplaincomp_pt1 _prflplaincomp_pt2
matorder prflplaincomp_tbl, matrix(prflplaincomp_tbl) over ifc(br90sec4 br90sec4plain br97sec4 br97sec4plain)
est2tex prflplaincomp, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(2)

* Firm performance variables
foreach yr in 90 97 {
local rownames : rownames firm`yr'pia_tbl
local rows : word count `rownames'
tokenize `rownames'
local newrownm ""
forvalues i = 1/`rows' {
  local ils1 = `i' - 1
  local indlbl "``i''"
  if substr("``i''",-3,3)=="_se" & length("``i''")==3  local indlbl "``ils1''`indlbl'"
  local newrownm "`newrownm' `indlbl'"
  }
mat rownames firm`yr'pia_tbl = `newrownm'
matorder firm`yr'pia_tbl, matrix(_frmpia`yr') ifc(ln_valadd_empl`yr' ln_sales_empl`yr' profit_cap`yr' lntfp`yr')
matorder _frmpia`yr', matrix(_tmp`yr') ifr(avgxbhat avgxbhat_se avgpsihat avgpsihat_se e(N) e(r2_w))
matrix roweq _tmp`yr' = 19`yr'
}
mat firmperf_tbl = _tmp90 \ _tmp97
local colnams : colnames firmperf_tbl
local colmax = colsof(firmperf_tbl)
tokenize `colnams'
forvalues i = 1/`colmax' {
    local coltitl = subinstr(subinstr("``i''","90","",.),"97","",.)
    matname firmperf_tbl `coltitl', columns(`i') explicit
    }
mat drop _tmp90 _tmp97 _frmpia90 _frmpia97
est2tex firmperf, replace dropall preserve ready mark(it) path(brazempl/tex/v1/tables) fancy

* Input variables
foreach yr in 90 97 {
matorder firm`yr'pia_tbl, matrix(_tmp`yr') ifc(ln_empl`yr' ln_cap`yr' ln_cap_empl`yr' labf_skil_tot`yr' labf_wh_tot`yr')
matorder _tmp`yr', matrix(_tmp`yr') over ifr(avgxbhat avgxbhat_se avgpsihat avgpsihat_se e(N) e(r2_w))
matrix roweq _tmp`yr' = 19`yr'
}
mat firminp_tbl = _tmp90 \ _tmp97
local colnams : colnames firminp_tbl
local colmax = colsof(firminp_tbl)
tokenize `colnams'
forvalues i = 1/`colmax' {
    local coltitl = subinstr(subinstr("``i''","90","",.),"97","",.)
    matname firminp_tbl `coltitl', columns(`i') explicit
    }
mat drop _tmp90 _tmp97
est2tex firminp, replace dropall preserve ready mark(it) path(brazempl/tex/v1/tables) fancy

/* Firm-regression comparison tables to France and US */

foreach yr in 90 97 {
tempfile br`yr'comp
matorder firm`yr'pia_tbl, matrix(firm`yr'pia_tbl) over ifr(avgxbhat avgxbhat_se avgpsihat avgpsihat_se)
local colnams : colnames firm`yr'pia_tbl
tokenize `colnams'
matorder firm`yr'pia_tbl, matrix(firmcomp`yr'_tbl) ifc(`1')
matrix roweq firmcomp`yr'_tbl = `1'
forvalues j = 2/9 {
    matorder firm`yr'pia_tbl, matrix(_tmp) over ifc(``j'')
    matrix roweq _tmp = ``j''
    mat firmcomp`yr'_tbl = firmcomp`yr'_tbl \ _tmp
    matname firmcomp`yr'_tbl br`yr', columns(1) explicit
    }
mat drop _tmp firm`yr'pia_tbl
matsave firmcomp`yr'_tbl, replace path(brazempl/tex/v1/tables)
use "brazempl/tex/v1/tables/firmcomp`yr'_tbl", clear
gen _brno = _n
preserve
    keep if substr(_rowname,-3,3)=="_se"
    sort _brno
    rename _brno _brnosd
    rename br`yr' br`yr'se
    save `br`yr'comp'
restore
drop if substr(_rowname,-3,3)=="_se"
sort _brno
merge using `br`yr'comp'
drop _br* _m
save "brazempl/tex/v1/tables/firmcomp`yr'_tbl", replace
drop _all
matload firmcomp`yr'_tbl, over path(brazempl/tex/v1/tables)
mat brfirmcomp`yr'_tbl = firmcomp`yr'_tbl
insheet using "brazempl/auxil/akmt-firm-secfe.csv", comma names clear
foreach var in fr92 us90 {
    replace `var'sd = abs(`var'sd)
    }
keep _rowname fr92* us90*
drop if fr92c==. & fr92s==. & us90c==. & us90s==.
save "brazempl/tex/v1/tables/firmcomp`yr'_tbl", replace
drop _all
matload firmcomp`yr'_tbl, over path(brazempl/tex/v1/tables)
mat firmcomp`yr'_tbl = firmcomp`yr'_tbl \ J(2,4,-999)
mat firmcomp`yr'_tbl = brfirmcomp`yr'_tbl , firmcomp`yr'_tbl
mat drop brfirmcomp`yr'_tbl
matorder firmcomp`yr'_tbl, matrix(firmcomp`yr'_b) ifc(br`yr' fr92coef us90coef)
matorder firmcomp`yr'_tbl, matrix(firmcomp`yr'_se) ifc(br`yr'se fr92sd us90sd)
est2tex firmcomp`yr', replace dropall preserve mark(it) path(brazempl/tex/v1/tables) fancy
}

mat firmcomp_tbl = firmcomp90_tbl , firmcomp97_tbl
matorder firmcomp_tbl, matrix(firmcomp_tbl) over ifc(br90 br97 fr92coef us90coef)
mat drop firmcomp90_tbl
mat drop firmcomp97_tbl
est2tex firmcomp, replace dropall preserve ready mark(it) path(brazempl/tex/v1/tables) fancy
mat drop firmcomp_tbl


/* Estimation Tables for Workers: Brazil by Sector, 1990 and 1997 */

foreach regname in indgrad edu noedu {
foreach yr in 90 97 {
  foreach sec in 4 5 2 1 {
    tempfile tf`yr'sec`sec'`regname'
    use "brazempl/tex/v1/wage/wage`yr'sec`sec'_tbl", clear
    gen int _brno = _n
    keep _rowname yr`yr'sec`sec'`regname' _brno
    sort _brno
    compress
    save `tf`yr'sec`sec'`regname''
    }
use `tf`yr'sec4`regname''
foreach sec in 5 2 1 {
    sort _brno
    merge _brno using `tf`yr'sec`sec'`regname''
    drop _m
    }
sort _brno
drop _brno
drop if yr`yr'sec1`regname'==-999 & yr`yr'sec2`regname'==-999 & yr`yr'sec4`regname'==-999 & yr`yr'sec5`regname'==-999
drop if _rowname[_n-1]=="_cons"
drop if _rowname=="_cons"
drop if substr(_rowname,1,2)=="e(" & _rowname~="e(N)" & _rowname~="e(r2_w)"
save "brazempl/tex/v1/tables/braz`yr'`regname'_tbl", replace
drop _all
matload braz`yr'`regname'_tbl, path(brazempl/tex/v1/tables) over
est2tex braz`yr'`regname', replace dropall preserve ready mark(it) fancy path(brazempl/tex/v1/tables)
}
mat braz`regname'_tbl = braz90`regname'_tbl , braz97`regname'_tbl
est2tex braz`regname', replace dropall preserve ready mark(it) fancy path(brazempl/tex/v1/tables)
}


/* OLS Estimation Tables for Workers: Brazil by Sector, 1990 and 1997 */

foreach regname in indgrad edu noedu {
foreach yr in 90 97 {
  foreach sec in 4 5 2 1 {
    tempfile tp`yr'sec`sec'`regname'
    use "brazempl/tex/v1/wage/wageplain`yr'sec`sec'_tbl", clear
    gen int _brno = _n
    keep _rowname yr`yr'sec`sec'`regname' _brno
    sort _brno
    compress
    save `tp`yr'sec`sec'`regname''
    }
use `tp`yr'sec4`regname''
foreach sec in 5 2 1 {
    sort _brno
    merge _brno using `tp`yr'sec`sec'`regname''
    drop _m
    }
sort _brno
drop _brno
drop if yr`yr'sec1`regname'==-999 & yr`yr'sec2`regname'==-999 & yr`yr'sec4`regname'==-999 & yr`yr'sec5`regname'==-999
drop if substr(_rowname,1,2)=="e(" & _rowname~="e(N)" & _rowname~="e(r2)"
save "brazempl/tex/v1/tables/brazplain`yr'`regname'_tbl", replace
drop _all
matload brazplain`yr'`regname'_tbl, path(brazempl/tex/v1/tables) over
est2tex brazplain`yr'`regname', replace dropall preserve ready mark(it) fancy path(brazempl/tex/v1/tables)
}
mat brazplain`regname'_tbl = brazplain90`regname'_tbl , brazplain97`regname'_tbl
est2tex brazplain`regname', replace dropall preserve ready mark(it) fancy path(brazempl/tex/v1/tables)
}

/* Comparison OLS and FE Estimation Tables for Workers: Brazil Manufacturing, 1990 and 1997 */

local sec 4
local regname edu 
foreach yr in 90 97 {
  foreach esttype in "" "plain" {
    tempfile yr`yr'sec`sec'`esttype'
    use "brazempl/tex/v1/wage/wage`esttype'`yr'sec`sec'_tbl", clear
    gen int _brno = _n
    keep _rowname yr`yr'sec`sec'`regname' _brno
    rename yr`yr'sec`sec'`regname' yr`yr'sec`sec'`esttype'
    sort _brno
    compress
    save `yr`yr'sec`sec'`esttype''
    }
  }
use `yr90sec4'
    sort _brno
    merge _brno using `yr90sec4plain'
    drop _m
foreach esttype in "" "plain" {
    sort _brno
    merge _brno using `yr97sec`sec'`esttype''
    drop _m
    }
sort _brno
drop _brno
drop if yr90sec4==-999 & yr90sec4plain==-999 & yr97sec4==-999 & yr90sec4plain==-999
drop if substr(_rowname,1,2)=="e(" & _rowname~="e(N)" & _rowname~="e(r2)" & _rowname~="e(r2_o)"
save "brazempl/tex/v1/tables/brazplaincomp_tbl", replace
drop _all
matload brazplaincomp_tbl, path(brazempl/tex/v1/tables) over
est2tex brazplaincomp, replace dropall preserve ready mark(it) fancy path(brazempl/tex/v1/tables) extracols(2)


/* Estimation Table Workers: Comparison Brazil 1990&97, France 1992 and U.S. 1990b */

foreach yr in 90 97 {
tempfile yr`yr'piasd yr`yr'piatbl
use `tf`yr'sec4edu', clear  /* use estimates from regression w/ education indicators */
drop if yr`yr'sec4edu==-999
drop if _rowname[_n-1]=="_cons"
drop if _rowname=="_cons"
drop if substr(_rowname,1,2)=="e(" & _rowname~="e(df_r)" & _rowname~="e(df_m)" & _rowname~="e(sigma_e)" & _rowname~="e(r2_w)"
preserve
    keep if substr(_rowname,-3,3)=="_se"
    sort _brno
    rename _brno _brnosd
    rename yr`yr'sec4edu yr`yr'piasd
    save `yr`yr'piasd'
restore
drop if substr(_rowname,-3,3)=="_se"
sort _brno
merge using `yr`yr'piasd'
drop _merge _br*
sort _rowname
save `yr`yr'piatbl'
insheet using "brazempl/auxil/akmt-worker-plantfe.csv", comma names clear
foreach var in fr86 us90a fr92 us90b {
    replace `var'stder = abs(`var'stder)
    }
keep _rowname fr92* us90b*
drop if fr92c==. & fr92s==. & us90bc==. & us90bs==.
gen _no = _n
sort _rowname
merge _rowname using `yr`yr'piatbl'
sort _no
drop _no _merge
save "brazempl/tex/v1/tables/compest`yr'_tbl", replace
drop _all
matload compest`yr'_tbl, path(brazempl/tex/v1/tables) over
matorder compest`yr'_tbl, matrix(compest`yr'_tbl) over ifc(yr`yr'sec4edu yr`yr'piasd fr92coeff fr92stder us90bcoeff us90bstder)
mat compest`yr'_b = compest`yr'_tbl[1..25,1] , compest`yr'_tbl[1..25,3] , compest`yr'_tbl[1..25,5]
mat compest`yr'_se = compest`yr'_tbl[1..25,2] , compest`yr'_tbl[1..25,4] , compest`yr'_tbl[1..25,6]
mat compest`yr'_e = compest`yr'_tbl[26..29,1] , compest`yr'_tbl[26..29,4] , compest`yr'_tbl[26..29,6]
mat drop compest`yr'_tbl
est2tex compest`yr', replace dropall preserve mark(it) path(brazempl/tex/v1/tables) fancy
}

use "brazempl/tex/v1/tables/compest90_tbl", clear
rename _rowname _rows90
drop fr92coeff us90bcoeff
gen _no = _n
merge using "brazempl/tex/v1/tables/compest97_tbl"
count if _merge~=3 |  _rows90~=_rowname
if `r(N)'~=0 {
  disp as err "rownames do not match"
  STOP
  }
sort _no
drop _no _merge _rows90
order _rowname yr90sec4edu yr97sec4edu fr92coeff us90bcoeff
save "brazempl/tex/v1/tables/compest9097_tbl", replace
drop _all
matload compest9097_tbl, path(brazempl/tex/v1/tables) over
est2tex compest9097, ready replace dropall preserve mark(it) path(brazempl/tex/v1/tables) fancy


/* Estimation Table Workers: Comparison Brazil 1990&97 noedu, France 1986 and U.S. 1990a (no education indicators) */

foreach yr in 90 97 {
tempfile nedu`yr'piasd nedu`yr'piatbl
use `tf`yr'sec4noedu', clear  /* use estimates from regression without education indicators */
drop if yr`yr'sec4noedu==-999
drop if _rowname[_n-1]=="_cons"
drop if _rowname=="_cons"
drop if substr(_rowname,1,2)=="e(" & _rowname~="e(df_r)" & _rowname~="e(df_m)" & _rowname~="e(sigma_e)" & _rowname~="e(r2_w)"
preserve
    keep if substr(_rowname,-3,3)=="_se"
    sort _brno
    rename _brno _brnosd
    rename yr`yr'sec4noedu nedu`yr'piasd
    save `nedu`yr'piasd'
restore
drop if substr(_rowname,-3,3)=="_se"
sort _brno
merge using `nedu`yr'piasd'
drop _merge _br*
sort _rowname
save `nedu`yr'piatbl'
insheet using "brazempl/auxil/akmt-worker-plantfe.csv", comma names clear
foreach var in fr86 us90a fr92 us90b {
    replace `var'stder = abs(`var'stder)
    }
keep _rowname fr86* us90a*
drop if fr86c==. & fr86s==. & us90ac==. & us90as==.
gen _no = _n
sort _rowname
merge _rowname using `nedu`yr'piatbl'
sort _no
drop _no _merge
save "brazempl/tex/v1/tables/compest`yr'_noedu_tbl", replace
drop _all
matload compest`yr'_noedu_tbl, path(brazempl/tex/v1/tables) over
matorder compest`yr'_noedu_tbl, matrix(compest`yr'_noedu_tbl) over ifc(yr`yr'sec4noedu nedu`yr'piasd fr86coeff fr86stder us90acoeff us90astder)
mat compest`yr'_noedu_b = compest`yr'_noedu_tbl[1..19,1] , compest`yr'_noedu_tbl[1..19,3] , compest`yr'_noedu_tbl[1..19,5]
mat compest`yr'_noedu_se = compest`yr'_noedu_tbl[1..19,2] , compest`yr'_noedu_tbl[1..19,4] , compest`yr'_noedu_tbl[1..19,6]
mat compest`yr'_noedu_e = compest`yr'_noedu_tbl[20..23,1] , compest`yr'_noedu_tbl[20..23,4] , compest`yr'_noedu_tbl[20..23,6]
mat drop compest`yr'_noedu_tbl
est2tex compest`yr'_noedu, replace dropall preserve mark(it) path(brazempl/tex/v1/tables) fancy
}

use "brazempl/tex/v1/tables/compest90_noedu_tbl", clear
rename _rowname _rows90
drop fr86coeff us90acoeff
gen _no = _n
merge using "brazempl/tex/v1/tables/compest97_noedu_tbl"
count if _merge~=3 |  _rows90~=_rowname
if `r(N)'~=0 {
  disp as err "rownames do not match"
  STOP
  }
sort _no
drop _no _merge _rows90
order _rowname yr90sec4noedu yr97sec4noedu fr86coeff us90acoeff
save "brazempl/tex/v1/tables/compest9097_noedu_tbl", replace
drop _all
matload compest9097_noedu_tbl, path(brazempl/tex/v1/tables) over
est2tex compest9097_noedu, ready replace dropall preserve mark(it) path(brazempl/tex/v1/tables) fancy


/* Summary Table Workers: Manufacturing Across Countries */
tempfile akmtsum
insheet using "brazempl/auxil/akmt-summdata.csv", comma names clear
gen _akmtno = _n
keep _rowname fr92mean us90mean _akmtno
sort _rowname
compress 
save `akmtsum'
use "brazempl/tex/v1/summ/summtex90sec4_tbl", clear
gen _brno = _n
sort _rowname
merge _rowname using `akmtsum'
tab _m
foreach var in mean sd {
    replace `var' = . if `var'==-999
    }
sort _brno _akmtno
drop _brno _akmtno _merge
save "brazempl/tex/v1/tables/compsumm_tbl", replace
drop _all
matload compsumm_tbl, path(brazempl/tex/v1/tables) over
est2tex compsumm, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy extracols(2)


/* Summary Statistics Workers: Sectors in Brazil 1990 and 1997 */
foreach yr in 90 97 {
use "brazempl/tex/v1/summ/summtex`yr'sec4_tbl", clear
foreach var in mean sd {
    replace `var' = . if `var'==-999
    }
replexp
rename mean mean`yr'sec4
rename sd sd`yr'sec4
foreach sec in 5 2 1 {
merge using "brazempl/tex/v1/summ/summtex`yr'sec`sec'_tbl"
drop _merge
foreach var in mean sd {
    replace `var' = . if `var'==-999
    }
replexp
rename mean mean`yr'sec`sec'
rename sd sd`yr'sec`sec'
}
drop if mean`yr'sec1==. & mean`yr'sec2==. & mean`yr'sec4==. & mean`yr'sec5==.
save "brazempl/tex/v1/tables/summtex`yr'_tbl", replace
drop _all
matload summtex`yr'_tbl, path(brazempl/tex/v1/tables) over
est2tex summtex`yr', replace dropall preserve ready p(brazempl/tex/v1/tables) fancy extracols(2 4 6)
local rows = rowsof(summtex`yr'_tbl)
matorder summtex`yr'_tbl, matrix(summtex`yr'pt1_tbl) ifc(mean`yr'sec4 sd`yr'sec4 mean`yr'sec5 sd`yr'sec5)
matorder summtex`yr'_tbl, matrix(summtex`yr'pt2_tbl) ifc(mean`yr'sec2 sd`yr'sec2 mean`yr'sec1 sd`yr'sec1)
est2tex summtex`yr'pt1, replace dropall preserve ready p(brazempl/tex/v1/tables) fancy extracols(2)
est2tex summtex`yr'pt2, replace dropall preserve ready p(brazempl/tex/v1/tables) fancy extracols(2)
}

mat summtex9097_tbl = summtex90pt1_tbl , summtex97pt1_tbl
matorder summtex9097_tbl, matrix(summtex9097_tbl) ifc(mean90sec4 sd90sec4 mean97sec4 sd97sec4)
est2tex summtex9097, replace dropall preserve ready p(brazempl/tex/v1/tables) fancy extracols(2)

*YR forvalues yr = 90/98 {
foreach yr in 90 97 {
  foreach sec in 4 5 2 1 {
    capture mat drop firm`yr'sec`sec'_tbl
    }
  }


/* Summary Statistics PIA: 1990 and 1997 */
matload piacnt_tbl, path(brazempl/tex/v1/summ) over
mat piacnt_tbl = piacnt_tbl[1..2,1] , J(2,1,-999) , piacnt_tbl[1..2,2] , J(2,1,-999)
foreach yr in 90 97 {
  matload summtex`yr'pia_tbl, path(brazempl/tex/v1/summ) over
  }
mat summtexpia_tbl = summtex90pia_tbl , summtex97pia_tbl
mat summtexpia_tbl = summtexpia_tbl \ piacnt_tbl
matname summtexpia_tbl mean90 sd90 mean97 sd97, columns(1..4) explicit
est2tex summtexpia, replace dropall preserve ready p(brazempl/tex/v1/tables) fancy extracols(2)

capture mat drop piacnt_tbl
*YR forvalues yr = 90/98 {
foreach yr in 90 97 {
  capture mat drop summtex`yr'pia_tbl
  }


/* Correlation comparison tables */

foreach regname in edu noedu {
tempfile fr92`regname' us90`regname'
insheet using "brazempl/auxil/fr92`regname'.csv", comma names clear
replace _rowname = "fr92:" + _rowname
rename ln_wage lnwage
rename stdev sdev
save `fr92`regname''
insheet using "brazempl/auxil/us90`regname'.csv", comma names clear
replace _rowname = "us90:" + _rowname
rename ln_wage lnwage
rename stdev sdev
save `us90`regname''
use "brazempl/tex/v1/corr/corr90sec4`regname'_tbl", clear
replace _rowname = "br90sec4:" + _rowname
append using "brazempl/tex/v1/corr/corr97sec4`regname'_tbl"
replace _rowname = "br97sec4:" + _rowname if substr(_rowname,1,4)~="br90"
append using `fr92`regname''
append using `us90`regname''
replace _rowname = "lnwage" if _rowname == "ln_wage"
save "brazempl/tex/v1/tables/corrcomp`regname'_tbl", replace
drop _all
matload corrcomp`regname'_tbl, over path(brazempl/tex/v1/tables)
* transform FFR 1992 into USD 1990
mat corrcomp`regname'_tbl[9,1] = corrcomp`regname'_tbl[9,1] - 1.67
mat corrcomp`regname'_tbl[11,1] = corrcomp`regname'_tbl[11,1] - 1.67
est2tex corrcomp`regname', replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
}


/* Inequality Measures */

local regname "edu"

local sec 4
foreach yr in 90 97 {
  foreach fe in "plain" "" {
    local reg "`fe'"
    if "`reg'"==""  local reg "plantfe"
    matload lnw`fe'comp`regname'sec`sec'yr`yr'_tbl, p(brazempl/tex/v1/corr) over dropall
    matrix coleq lnw`fe'comp`regname'sec`sec'yr`yr'_tbl = `reg' `reg' `reg' `reg'
    }
  mat lnwcomp`yr'manuf_tbl = lnwcomp`regname'sec`sec'yr`yr'_tbl , lnwplaincomp`regname'sec`sec'yr`yr'_tbl
  mat roweq lnwcomp`yr'manuf_tbl = inq
  est2tex lnwcomp`yr'manuf, replace dropall ready digits(4) fancy p(brazempl/tex/v1/tables) extracols(4)
  mat drop lnwcomp`regname'sec`sec'yr`yr'_tbl lnwplaincomp`regname'sec`sec'yr`yr'_tbl
  }

foreach yr in 90 97 {
  foreach sec in 1 2 4 5 {
    foreach fe in "plain" "" {
      local reg "`fe'"
      if "`reg'"==""  local reg "plantfe"
      matload lnw`fe'comp`regname'sec`sec'yr`yr'_tbl, p(brazempl/tex/v1/corr) over dropall
      matorder lnw`fe'comp`regname'sec`sec'yr`yr'_tbl, matrix(lnw`fe'comp`regname'sec`sec'yr`yr'_tbl) ifc(sqcoefvar) over
      matrix colnames lnw`fe'comp`regname'sec`sec'yr`yr'_tbl = sec`sec'
      matrix coleq lnw`fe'comp`regname'sec`sec'yr`yr'_tbl = `reg'
      }
    }
  mat lnwcomp`yr'sqcfdev_tbl = lnwcomp`regname'sec1yr`yr'_tbl , lnwcomp`regname'sec2yr`yr'_tbl , lnwcomp`regname'sec4yr`yr'_tbl , lnwcomp`regname'sec5yr`yr'_tbl , lnwplaincomp`regname'sec1yr`yr'_tbl , lnwplaincomp`regname'sec2yr`yr'_tbl , lnwplaincomp`regname'sec4yr`yr'_tbl , lnwplaincomp`regname'sec5yr`yr'_tbl
  mat roweq lnwcomp`yr'sqcfdev_tbl = inq
  matorder lnwcomp`yr'sqcfdev_tbl, matrix(lnwcomp`yr'sqcfdev_tbl) over ifc(plantfe:sec4 plain:sec4 plantfe:sec5 plain:sec5 plantfe:sec2 plain:sec2 plantfe:sec1 plain:sec1)
  est2tex lnwcomp`yr'sqcfdev, replace dropall ready digits(4) fancy p(brazempl/tex/v1/tables) extracols(2 4 6)
  mat drop lnwcomp`regname'sec1yr`yr'_tbl lnwcomp`regname'sec2yr`yr'_tbl lnwcomp`regname'sec4yr`yr'_tbl lnwcomp`regname'sec5yr`yr'_tbl lnwplaincomp`regname'sec1yr`yr'_tbl lnwplaincomp`regname'sec2yr`yr'_tbl lnwplaincomp`regname'sec4yr`yr'_tbl lnwplaincomp`regname'sec5yr`yr'_tbl
  }

mat coleq lnwcomp90sqcfdev_tbl = yr1990
mat coleq lnwcomp97sqcfdev_tbl = yr1997
mat lnwcomp9097manuf_tbl = lnwcomp90sqcfdev_tbl , lnwcomp97sqcfdev_tbl
matorder lnwcomp9097manuf_tbl, matrix(lnwcomp9097manuf_tbl) over ifc(yr1990:plantfe_sec4 yr1990:plain_sec4 yr1997:plantfe_sec4 yr1997:plain_sec4)
est2tex lnwcomp9097manuf, replace dropall ready digits(4) fancy p(brazempl/tex/v1/tables) extracols(2)

foreach table in lnwcomp90sqcfdev lnwcomp97sqcfdev lnwcomp9097manuf {
tempname tot
matorder `table'_tbl, matrix(`tot') ifr(inq:lnwage)
matorder `table'_tbl, matrix(`table'_pc_tbl) ifr(inq:xbhat inq:xbhat_exper inq:xbhat_occu inq:xbhat_edu inq:xbhat_sex inq:psihat inq:eiw)
local rows = rowsof(`table'_pc_tbl)
local cols = colsof(`table'_pc_tbl)
forvalues i = 1/`rows' {
  forvalues j = 1/`cols' {
    mat `table'_pc_tbl[`i',`j'] = `table'_pc_tbl[`i',`j']/`tot'[1,`j']
    }
  }
est2tex `table'_pc, replace dropall ready digits(3) fancy p(brazempl/tex/v1/tables) extracols(2 4 6)
}

cd "$home"
