version 8
clear
set matsize 180
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

/* Load variable names and save for est2tex */

insheet using "brazempl/tex/regressor-list.tex", delimiter("&") clear
rename v1 _rowname
rename v2 _rowlbl
replace _rowname = trim(_rowname)
replace _rowlbl = trim(_rowlbl)
drop if _rowname=="" & _rowlbl==""
sort _rowname
compress
save "brazempl/tex/v1/corr/corr90sec1edu_rowlbl", replace
save "brazempl/tex/v1/corr/corr90sec2edu_rowlbl", replace
save "brazempl/tex/v1/corr/corr90sec4edu_rowlbl", replace
save "brazempl/tex/v1/corr/corr90sec5edu_rowlbl", replace
save "brazempl/tex/v1/corr/corr97sec1edu_rowlbl", replace
save "brazempl/tex/v1/corr/corr97sec2edu_rowlbl", replace
save "brazempl/tex/v1/corr/corr97sec4edu_rowlbl", replace
save "brazempl/tex/v1/corr/corr97sec5edu_rowlbl", replace
save "brazempl/tex/v1/tables/wrkrfrmfe_rowlbl", replace
save "brazempl/tex/v1/tables/wrkrfrmfe_nosecfe_rowlbl", replace
save "brazempl/tex/v1/tables/wrkrfrmfe_nosecfe_rais_rowlbl", replace
save "brazempl/tex/v1/tables/wrkrfrmfe_rais_rowlbl", replace
clear

* Cross-sectoral competition regressions
matload wrkrfrmfe_pia_tbl, p(brazempl/tex/v1/sec) over
matload wrkrfrmfe_rais_tbl, p(brazempl/tex/v1/sec) over
local rows = rowsof(wrkrfrmfe_pia_tbl)
mat wrkrfrmfe_tbl = wrkrfrmfe_rais_tbl[1..`rows',3..4] , wrkrfrmfe_pia_tbl[1..`rows',3..4]
matsave wrkrfrmfe_tbl, p(brazempl/tex/v1/tables) replace
drop if rais_avgxbhat_indyr==-999 & avgxbhat_indyr==-999 & rais_avgpsihat_indyr==-999 & avgpsihat_indyr==-999
save "brazempl/tex/v1/tables/wrkrfrmfe_tbl", replace
matload wrkrfrmfe_tbl, dropall p(brazempl/tex/v1/tables) over
est2tex wrkrfrmfe, replace dropall preserve ready mark(it) path(brazempl/tex/v1/tables) fancy extracols(2)

* Cross-sectoral competition regressions with and without sector dummies
mat wrkrfrmfe_nosecfe_rais_tbl = wrkrfrmfe_rais_tbl[1..`rows',3] , wrkrfrmfe_rais_tbl[1..`rows',5] , wrkrfrmfe_rais_tbl[1..`rows',4] , wrkrfrmfe_rais_tbl[1..`rows',6]
matsave wrkrfrmfe_nosecfe_rais_tbl, p(brazempl/tex/v1/tables) replace
drop if rais_avgxbhat_indyr==-999 & rais_avgxbhat_indyr_nosecfe==-999 & rais_avgpsihat_indyr==-999 & rais_avgpsihat_indyr_nosecfe==-999
save "brazempl/tex/v1/tables/wrkrfrmfe_nosecfe_rais_tbl", replace
matload wrkrfrmfe_nosecfe_rais_tbl, dropall p(brazempl/tex/v1/tables) over
est2tex wrkrfrmfe_nosecfe_rais, replace dropall preserve ready mark(it) path(brazempl/tex/v1/tables) fancy extracols(2)
mat wrkrfrmfe_nosecfe_tbl = wrkrfrmfe_rais_tbl[1..`rows',4] , wrkrfrmfe_rais_tbl[1..`rows',6] , wrkrfrmfe_pia_tbl[1..`rows',4] , wrkrfrmfe_pia_tbl[1..`rows',6]
local colnam : colnam wrkrfrmfe_nosecfe_tbl
local cols : word count "`colnam'"
tokenize `colnam'
forvalues j = 1/`cols' {
  local `j' = subinstr("``j''","_indyr","",.)
  matname wrkrfrmfe_nosecfe_tbl ``j'', columns(`j') explicit
  }
matsave wrkrfrmfe_nosecfe_tbl, p(brazempl/tex/v1/tables) replace
drop if avgpsihat_indyr==-999 & avgpsihat_indyr_nosecfe==-999 & rais_avgpsihat_indyr==-999 & rais_avgpsihat_indyr_nosecfe==-999
save "brazempl/tex/v1/tables/wrkrfrmfe_nosecfe_tbl", replace
matload wrkrfrmfe_nosecfe_tbl, dropall p(brazempl/tex/v1/tables) over
matname wrkrfrmfe_nosecfe_tbl rais_psihat_indyr rais_psihat_indyr_nosec pia_psihat_indyr pia_psihat_indyr_nosec, columns(1..4) explicit
est2tex wrkrfrmfe_nosecfe, replace dropall preserve ready mark(it) path(brazempl/tex/v1/tables) fancy extracols(2)

* Cross-sectoral competition regressions with omitted regressors
mat wrkrfrmfe_rais_tbl = wrkrfrmfe_rais_tbl[1..`rows',7..9] , wrkrfrmfe_rais_tbl[1..`rows',3]
matsave wrkrfrmfe_rais_tbl, p(brazempl/tex/v1/tables) replace
drop if rais_avgxbhat_indyr_v2==-999 & rais_avgxbhat_indyr_v3==-999 & rais_avgxbhat_indyr_v4==-999 & rais_avgxbhat_indyr==-999
save "brazempl/tex/v1/tables/wrkrfrmfe_rais_tbl", replace
matload wrkrfrmfe_rais_tbl, dropall p(brazempl/tex/v1/tables) over
est2tex wrkrfrmfe_rais, replace dropall preserve ready mark(it) path(brazempl/tex/v1/tables) fancy

* Worker counts per RAIS sector and year
matload cntfemtot, path(rais-sp/rais) over
matload cntmasctot, path(rais-sp/rais) over
mat rename cntfemtot cntfemtot_tbl
mat rename cntmasctot cntmasctot_tbl
est2tex cntfemtot, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
est2tex cntmasctot, replace dropall preserve ready path(brazempl/tex/v1/tables) fancy

* Evolution of fixed effect and its sdev over time
foreach regname in edu noedu {
 foreach stat in mean sdev {
*YR   mat feevol`regname' = J(12,9,-999)
  mat feevol`regname' = J(12,2,-999)
*YR   matname feevol`regname' yr90 yr91 yr92 yr93 yr94 yr95 yr96 yr97 yr98, columns(1..9) explicit
  matname feevol`regname' yr90 yr97, columns(1..2) explicit
  matname feevol`regname' agric:lnwage agric:avgxbhat agric:avgpsihat commrc:lnwage commrc:avgxbhat commrc:avgpsihat manuf:lnwage manuf:avgxbhat manuf:avgpsihat srvcs:lnwage srvcs:avgxbhat srvcs:avgpsihat, rows(1..12) explicit
  local col = 0
*YR   forvalues yr = 90/98 {
  foreach yr in 90 97 {
    local col = `col' + 1
    local i = 0
    foreach sec in 1 2 4 5 {
      local i = `i' + 1
      local row1 = `i'*3 - 2
      local row2 = `i'*3 - 1
      local row3 = `i'*3
      use "brazempl/tex/v1/corr/corr`yr'sec`sec'`regname'_tbl", clear
      mat feevol`regname'[`row1',`col'] = `stat'[1]
      mat feevol`regname'[`row2',`col'] = `stat'[2]
      mat feevol`regname'[`row3',`col'] = `stat'[3]
     }
   }
  mat rename feevol`regname' fe`stat'`regname'_tbl
  est2tex fe`stat'`regname', replace dropall preserve ready path(brazempl/tex/v1/tables) fancy
  }
 }

* Reformat estimation output tables
foreach var in indgrad edu noedu {
*YR forvalues yr = 90/98 {
   foreach yr in 90 97 {
    foreach sec in 1 2 4 5 {
      matload corr`yr'sec`sec'`var'_tbl, dropall path(brazempl/tex/v1/corr) over
      est2tex corr`yr'sec`sec'`var', replace dropall preserve ready digits(3) fancy p(brazempl/tex/v1/corr)
      }
    }
  }

cd "$home"
