version 8
clear
set matsize 180
set logtype text
set mem 800m
set more off
adopath + "brazdspl/%stata/ado"

cd "$root"

capture program drop summtex
program define summtex
    syntax [varlist] [, Path(string) PREcision(real 0) DIGits(integer 3) Name(string) ]
    local nvar : word count `varlist'
    local rownum = `nvar' + 1
    matrix `name'_tbl = J(`rownum',2,-999)
    matname `name'_tbl mean sd, columns(1..2) explicit
    local i 0
    foreach var of local varlist {
      local i = `i' + 1
      qui summ `var'
      if `r(N)'~=0 {
        matrix `name'_tbl[`i',1] = `r(mean)'
        matrix `name'_tbl[`i',2] = `r(sd)'
        }
      else {
        matrix `name'_tbl[`i',1] = -999
        matrix `name'_tbl[`i',2] = -999
        }
      matname `name'_tbl `var', rows(`i') explicit
      }
    qui count
    matrix `name'_tbl[`rownum',1] = `r(N)'
    matname `name'_tbl r(N), rows(`rownum') explicit
    est2tex `name', replace dropall preserve precision(`precision') digits(`digits') ready path(`path')
end

capture program drop tabl2tex
program define tabl2tex
    * NOTE: TOTALS ARE STILL UNWEIGHTED, NO PROPER AVERAGES ARE PRODUCED
    * USE SUMM FUNCTION IN FUTURE TO CALCULATE MARGINALS
    version 8
    syntax [varlist] [if] [in] [pweight fweight] [, Type(string) Rowvar(varname) Colvar(varname) ROWLabel(string) COLLabel(string) Path(string) Name(string) NOTOTal FANCY REPLACE]
    args var
    local var = trim(subinstr("`var'",`","',"",.))
    if "`type'"=="sum" & "`nototal'"=="" {
        local totopt = "row col"
        }
    if "`weight'"~="" {
        local wghtopt = "[`weight'`exp']"
        }
    * disp "`var': table `rowvar' `colvar' `if' `in' `wghtopt', c(`type' `var') `totopt'"
    * disp "`var': collapse (`type') `var' `if' `in' `wghtopt', by(`rowvar' `colvar') fast"
    confirm numeric variable `rowvar' `colvar'
    foreach colrow in col row {
      if "``colrow'label'" == "" {
        local `colrow'label : value label ``colrow'var'
        if "``colrow'label'" == "" {
            tempname lblnam
            qui count
            forvalues i = 1/`r(N)' {
                local lbltit = ``colrow'var'[`i']
                label define `lblnam' `lbltit' "`lbltit'", modify
                }
             local `colrow'label = "`lblnam'"
             }
           }
      label values ``colrow'var' ``colrow'label'
      }
    table `rowvar' `colvar' `if' `in' `wghtopt', c(`type' `var') `totopt'
    tempfile collblf
    qui label save `collabel' using `collblf'.do
    collapse (`type') `var' `if' `in' `wghtopt', by(`rowvar' `colvar') fast
    rename `var' `var'_
    qui reshape wide `var'_, i(`rowvar') j(`colvar')
    qui duplicates drop
    rename `rowvar' _rowname
    if "`totopt'" ~= "" {
      egen _total = r`type'(`var'_*)
      qui count
      local newobs = `r(N)' + 1
      qui set obs `newobs'
      qui summ _rowname
      local totlno = -999
      qui replace _rowname = `totlno' in `newobs'
      label define `rowlabel' `totlno' "_total", modify
      foreach jvar of varlist `var'_* _total {
        qui summ `jvar', meanonly
        if `r(N)' > 0 {
            qui replace `jvar' = `r(`type')' in `newobs'
            }
        }
      }
    qui do `collblf'.do
    foreach jvar of varlist `var'_* {
        local cntr = substr("`jvar'",-index(reverse("`jvar'"),"_")+1,length("`jvar'")-index(reverse("`jvar'"),"_"))
        * disp "`cntr'"
        local jvarnam : label `collabel' `cntr'
        * disp "`jvarnam'"
        capture rename `jvar' `jvarnam'
        }
    decode _rowname, gen(`rowvar')
    drop _rowname
    rename `rowvar' _rowname
    order _rowname
    qui replace _rowname = substr(_rowname,1,20)
    qui replace _rowname = subinstr(_rowname," ","_",.)
    qui replace _rowname = subinstr(_rowname,";","_",.)
    qui replace _rowname = subinstr(_rowname,",","_",.)
    qui replace _rowname = subinstr(_rowname,".","_",.)
    qui replace _rowname = subinstr(_rowname,":","_",.)
    qui replace _rowname = subinstr(_rowname,"!","_",.)
    qui compress
    tempname tmpname
    qui save `path'/`tmpname'_tbl, replace
    qui matload `tmpname'_tbl, p(`path') over dropall
    local erasfile = subinstr("`path'" + "\" + "`tmpname'_tbl.dta","/",`"\"',.)
    erase `erasfile'
    mat rename `tmpname'_tbl `name'_tbl
    est2tex `name', ready `replace' preserve path(`path') `fancy'
end


foreach infrm in informl forml all {
  foreach yr in 90 97 {
    disp
    disp in green "Year: " in yellow "19`yr'" in green ", Sectors: " in yellow "all"
    disp
    use "brazempl/pnad/use-pnad-`yr'", clear
    if "`infrm'"=="informl" {
      keep if indinfrm
      }
    if "`infrm'"=="forml" {
      keep if ~indinfrm
      }
    keep lnwage indfem indprim indhigh indscoll indgrad sector
    gen byte indnocoll = (indprim==1 | indhigh==1)
    label var indnocoll "Less than college education"
    keep lnwage sector indfem indnocoll
    order lnwage sector indfem indnocoll
    preserve
    foreach var in indfem indnocoll {
      restore, preserve
      tabl2tex lnwage, type(mean) r(`var') c(sector) p(brazempl/tex/pnad/summ) name(lnwmean`yr'`var'_`infrm') fancy replace
      restore, preserve
      tabl2tex lnwage, type(count) r(`var') c(sector) p(brazempl/tex/pnad/summ) name(count`yr'`var'_`infrm') fancy replace
      restore, preserve
      tabl2tex lnwage, type(sd) r(`var') c(sector) p(brazempl/tex/pnad/summ) name(sdv`yr'`var'_`infrm') fancy replace
      }
    restore
    }
  }

foreach infrm in informl forml all {
 *YR forvalues yr = 90/98 {}
 foreach yr in 90 97 {
  foreach sec in 1 2 4 5 {
    disp
    disp in green "Year: " in yellow "19`yr'" in green ", Sector: " in yellow "`sec'"
    disp
    use "brazempl/pnad/use-pnad-`yr'", clear
    if "`infrm'"=="informl" {
      keep if indinfrm
      }
    if "`infrm'"=="forml" {
      keep if ~indinfrm
      }
    keep if sector==`sec'
    order lnwage potexper potxper2 potxper3 potxper4 indprim indhigh indscoll indgrad indfem indblue
    keep  lnwage potexper potxper2 potxper3 potxper4 indprim indhigh indscoll indgrad indfem indblue
    foreach var in lnwage potexper potxper2 potxper3 potxper4 indprim indhigh indscoll indgrad indblue {
      local dattyp = ""
      if substr("`var'",1,3)=="ind" {
          local dattyp = "byte"
          }
      gen `dattyp' fem_`var' = indfem * `var'
      local lbl : variable label `var'
      local lbl = subinstr("`lbl'"," (at plant)","",.)
      local lbl = subinstr("`lbl'"," Term","",.)
      local lbl = subinstr("`lbl'"," Occupation","",.)
      local lbl = subinstr("`lbl'"," Education","",.)
      local lbl = "Fem. " + "`lbl'" + " Interact."
      label var fem_`var' "`lbl'"
      }
    compress
    * foreach var in potxper tenr {
    *   forvalues i = 2/4 {
    *     replace `var'`i' = `var'`i' / 1.0e+`i'
    *     local pot = 10^`i'
    *     local lbl : variable label `var'`i'
    *     label var `var'`i' "`lbl' (/`pot')"
    *     replace fem_`var'`i' = fem_`var'`i' / 1.0e+`i'
    *     local lbl : variable label fem_`var'`i'
    *     label var fem_`var'`i' "`lbl' (/`pot')"
    *     }
    *   }
    order lnwage potexper potxper2 potxper3 potxper4 indprim indhigh indscoll indgrad indblue indfem fem_lnwage fem_potexper fem_potxper2 fem_potxper3 fem_potxper4 fem_indprim fem_indhigh fem_indscoll fem_indgrad fem_indblue
    summtex *, path(brazempl/tex/pnad/summ) digits(4) name(summtex`yr'sec`sec'`infrm')
  }
 }
}

cd "$home"
